@@ -2,6 +2,7 @@ package actionlint
 
 import (
 	"fmt"
+	"sort"
 	"strconv"
 	"strings"
 
@@ -41,6 +42,32 @@ type String struct {
 	Pos *Pos
 }
 
+// ContainsExpression checks if the given string contains a ${{ }} placeholder or not. This function
+// is identical to String.ContainsExpression method except for taking a standard string value.
+func ContainsExpression(s string) bool {
+	i := strings.Index(s, "${{")
+	return i >= 0 && i < strings.Index(s, "}}")
+}
+
+// ContainsExpression returns whether the string contains at least one ${{ }} expression.
+func (s *String) ContainsExpression() bool {
+	return ContainsExpression(s.Value)
+}
+
+func isExprAssigned(s string) bool {
+	v := strings.TrimSpace(s)
+	// Do not check `strings.Count(s.Value, "}}") == 1` because it might appear in JSON string
+	//   if: ${{ env.foo == '{"foo": {"bar": true}}' }}
+	return strings.HasPrefix(v, "${{") &&
+		strings.HasSuffix(v, "}}") &&
+		strings.Count(v, "${{") == 1
+}
+
+// IsExpressionAssigned returns whether a single expression is assigned to the string.
+func (s *String) IsExpressionAssigned() bool {
+	return isExprAssigned(s.Value)
+}
+
 // Bool represents generic boolean value in YAML file with position.
 type Bool struct {
 	// Value is a raw value of the bool string.
@@ -158,6 +185,8 @@ const (
 	WorkflowDispatchEventInputTypeNone WorkflowDispatchEventInputType = iota
 	// WorkflowDispatchEventInputTypeString is string type of input of workflow_dispatch event.
 	WorkflowDispatchEventInputTypeString
+	// WorkflowDispatchEventInputTypeNumber is number type of input of workflow_dispatch event.
+	WorkflowDispatchEventInputTypeNumber
 	// WorkflowDispatchEventInputTypeBoolean is boolean type of input of workflow_dispatch event.
 	WorkflowDispatchEventInputTypeBoolean
 	// WorkflowDispatchEventInputTypeChoice is choice type of input of workflow_dispatch event.
@@ -486,7 +515,8 @@ func (o *RawYAMLObject) String() string {
 	for n, p := range o.Props {
 		qs = append(qs, fmt.Sprintf("%q: %s", n, p.String()))
 	}
-	return fmt.Sprintf("{%s}", strings.Join(qs, ", "))
+	sort.Strings(qs)
+	return "{" + strings.Join(qs, ", ") + "}"
 }
 
 // RawYAMLArray is raw YAML sequence value.
@@ -525,11 +555,13 @@ func (a *RawYAMLArray) Pos() *Pos {
 }
 
 func (a *RawYAMLArray) String() string {
-	qs := make([]string, 0, len(a.Elems))
+	var b quotesBuilder
+	b.inner.WriteRune('[')
 	for _, v := range a.Elems {
-		qs = append(qs, v.String())
+		b.append(v.String())
 	}
-	return fmt.Sprintf("[%s]", strings.Join(qs, ", "))
+	b.inner.WriteRune(']')
+	return b.build()
 }
 
 // RawYAMLString is raw YAML scalar value.
