@@ -1,6 +1,7 @@
 package actionlint
 
 import (
+	"path"
 	"strings"
 )
 
@@ -8,15 +9,19 @@ type runnerOSCompat uint
 
 const (
 	compatInvalid                   = 0
-	compatUbuntu1804 runnerOSCompat = 1 << iota
-	compatUbuntu2004
+	compatUbuntu2004 runnerOSCompat = 1 << iota
 	compatUbuntu2204
 	compatMacOS1015
 	compatMacOS110
 	compatMacOS120
+	compatMacOS120L
 	compatMacOS120XL
 	compatMacOS130
+	compatMacOS130L
 	compatMacOS130XL
+	compatMacOS140
+	compatMacOS140L
+	compatMacOS140XL
 	compatWindows2016
 	compatWindows2019
 	compatWindows2022
@@ -25,19 +30,33 @@ const (
 // https://docs.github.com/en/actions/using-github-hosted-runners/about-github-hosted-runners
 var allGitHubHostedRunnerLabels = []string{
 	"windows-latest",
+	"windows-latest-8-cores",
 	"windows-2022",
 	"windows-2019",
 	"windows-2016",
 	"ubuntu-latest",
+	"ubuntu-latest-4-cores",
+	"ubuntu-latest-8-cores",
+	"ubuntu-latest-16-cores",
 	"ubuntu-22.04",
 	"ubuntu-20.04",
-	"ubuntu-18.04",
 	"macos-latest",
 	"macos-latest-xl",
+	"macos-latest-xlarge",
+	"macos-latest-large",
+	"macos-14-xl",
+	"macos-14-xlarge",
+	"macos-14-large",
+	"macos-14",
+	"macos-14.0",
 	"macos-13-xl",
+	"macos-13-xlarge",
+	"macos-13-large",
 	"macos-13",
 	"macos-13.0",
 	"macos-12-xl",
+	"macos-12-xlarge",
+	"macos-12-large",
 	"macos-12",
 	"macos-12.0",
 	"macos-11",
@@ -61,28 +80,42 @@ var selfHostedRunnerPresetOtherLabels = []string{
 }
 
 var defaultRunnerOSCompats = map[string]runnerOSCompat{
-	"ubuntu-latest":   compatUbuntu2204,
-	"ubuntu-22.04":    compatUbuntu2204,
-	"ubuntu-20.04":    compatUbuntu2004,
-	"ubuntu-18.04":    compatUbuntu1804,
-	"macos-13-xl":     compatMacOS130XL,
-	"macos-13":        compatMacOS130,
-	"macos-13.0":      compatMacOS130,
-	"macos-latest-xl": compatMacOS120XL,
-	"macos-latest":    compatMacOS120,
-	"macos-12-xl":     compatMacOS120XL,
-	"macos-12":        compatMacOS120,
-	"macos-12.0":      compatMacOS120,
-	"macos-11":        compatMacOS110,
-	"macos-11.0":      compatMacOS110,
-	"macos-10.15":     compatMacOS1015,
-	"windows-latest":  compatWindows2022,
-	"windows-2022":    compatWindows2022,
-	"windows-2019":    compatWindows2019,
-	"windows-2016":    compatWindows2016,
-	"linux":           compatUbuntu2204 | compatUbuntu2004 | compatUbuntu1804, // Note: "linux" does not always indicate Ubuntu. It might be Fedora or Arch or ...
-	"macos":           compatMacOS130 | compatMacOS130XL | compatMacOS120 | compatMacOS120XL | compatMacOS110 | compatMacOS1015,
-	"windows":         compatWindows2022 | compatWindows2019 | compatWindows2016,
+	"ubuntu-latest":          compatUbuntu2204,
+	"ubuntu-latest-4-cores":  compatUbuntu2204,
+	"ubuntu-latest-8-cores":  compatUbuntu2204,
+	"ubuntu-latest-16-cores": compatUbuntu2204,
+	"ubuntu-22.04":           compatUbuntu2204,
+	"ubuntu-20.04":           compatUbuntu2004,
+	"macos-14-xl":            compatMacOS140XL,
+	"macos-14-xlarge":        compatMacOS140XL,
+	"macos-14-large":         compatMacOS140L,
+	"macos-14":               compatMacOS140,
+	"macos-14.0":             compatMacOS140,
+	"macos-13-xl":            compatMacOS130XL,
+	"macos-13-xlarge":        compatMacOS130XL,
+	"macos-13-large":         compatMacOS130L,
+	"macos-13":               compatMacOS130,
+	"macos-13.0":             compatMacOS130,
+	"macos-latest-xl":        compatMacOS120XL,
+	"macos-latest-xlarge":    compatMacOS120XL,
+	"macos-latest-large":     compatMacOS120L,
+	"macos-latest":           compatMacOS120,
+	"macos-12-xl":            compatMacOS120XL,
+	"macos-12-xlarge":        compatMacOS120XL,
+	"macos-12-large":         compatMacOS120L,
+	"macos-12":               compatMacOS120,
+	"macos-12.0":             compatMacOS120,
+	"macos-11":               compatMacOS110,
+	"macos-11.0":             compatMacOS110,
+	"macos-10.15":            compatMacOS1015,
+	"windows-latest":         compatWindows2022,
+	"windows-latest-8-cores": compatWindows2022,
+	"windows-2022":           compatWindows2022,
+	"windows-2019":           compatWindows2019,
+	"windows-2016":           compatWindows2016,
+	"linux":                  compatUbuntu2204 | compatUbuntu2004, // Note: "linux" does not always indicate Ubuntu. It might be Fedora or Arch or ...
+	"macos":                  compatMacOS130 | compatMacOS130L | compatMacOS130XL | compatMacOS120 | compatMacOS120L | compatMacOS120XL | compatMacOS110 | compatMacOS1015,
+	"windows":                compatWindows2022 | compatWindows2019 | compatWindows2016,
 }
 
 // RuleRunnerLabel is a rule to check runner label like "ubuntu-latest". There are two types of
@@ -181,7 +214,12 @@ func (rule *RuleRunnerLabel) verifyRunnerLabel(label *String) runnerOSCompat {
 
 	known := rule.getKnownLabels()
 	for _, k := range known {
-		if strings.EqualFold(l, k) {
+		m, err := path.Match(k, l)
+		if err != nil {
+			rule.Errorf(label.Pos, "label pattern %q is an invalid glob. kindly check list of labels in actionlint.yaml config file: %v", k, err)
+			return compatInvalid
+		}
+		if m {
 			return compatInvalid
 		}
 	}
@@ -236,7 +274,7 @@ func (rule *RuleRunnerLabel) tryToGetLabelsInMatrix(label *String, m *Matrix) []
 	if m.Rows != nil {
 		if row, ok := m.Rows[prop]; ok {
 			for _, v := range row.Values {
-				if s, ok := v.(*RawYAMLString); ok && !containsExpression(s.Value) {
+				if s, ok := v.(*RawYAMLString); ok && !ContainsExpression(s.Value) {
 					labels = append(labels, &String{s.Value, false, s.Pos()})
 				}
 			}
@@ -247,7 +285,7 @@ func (rule *RuleRunnerLabel) tryToGetLabelsInMatrix(label *String, m *Matrix) []
 		for _, combi := range m.Include.Combinations {
 			if combi.Assigns != nil {
 				if assign, ok := combi.Assigns[prop]; ok {
-					if s, ok := assign.Value.(*RawYAMLString); ok && !containsExpression(s.Value) {
+					if s, ok := assign.Value.(*RawYAMLString); ok && !ContainsExpression(s.Value) {
 						labels = append(labels, &String{s.Value, false, s.Pos()})
 					}
 				}
